import * as i0 from '@angular/core';
import { Component, ViewEncapsulation, Optional, HostBinding, Input, Directive, Inject, NgModule } from '@angular/core';
import * as i1 from '@angular/forms';
import { FormControl } from '@angular/forms';
import * as i2 from 'angular-i18next';
import { I18NEXT_NAMESPACE, I18NextModule } from 'angular-i18next';

class ValidationMessage {
    constructor(key = '', params = null) {
        this.key = '';
        this.key = key;
        this.params = params;
    }
}

class ValidationMessageComponent {
    constructor(formControlName, formGroupName) {
        this.formControlName = formControlName;
        this.for = null;
        this.acd = formControlName || formGroupName;
        if (this.acd != null)
            this.for = this.acd.control;
    }
    get standalone() {
        return this.acd == null;
    }
    get messages() {
        return this.getValidationMessages();
    }
    get firstMessage() {
        return this.messages[0] ? this.messages[0] : new ValidationMessage();
    }
    get controlPath() {
        if (this.acd == null)
            return '';
        return this.acd.path.join('.');
    }
    getValidationMessages() {
        if (this.for == null || this.for.errors == null)
            return [];
        let messages = [];
        let keys = Object.keys(this.for.errors);
        keys.forEach(k => {
            let errValue = this.for.errors[k];
            let params = null;
            if (errValue instanceof Object)
                params = errValue;
            else if (errValue !== true) {
                params = {};
                params[k] = errValue;
            }
            messages.push(new ValidationMessage(k, params));
        });
        return messages;
    }
}
ValidationMessageComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: ValidationMessageComponent, deps: [{ token: i1.FormControlName, optional: true }, { token: i1.FormGroupName, optional: true }], target: i0.ɵɵFactoryTarget.Component });
ValidationMessageComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.2.2", type: ValidationMessageComponent, selector: "validation-message", inputs: { for: "for" }, host: { properties: { "class.standalone": "this.standalone" } }, ngImport: i0, template: `
      <div class="error-container">{{ firstMessage.key + (firstMessage.params ? '(' + firstMessage.params + ')' : '') }}</div>
      <i class="error-icon"></i>
    `, isInline: true, styles: ["validation-message{display:none;width:100%}validation-message.standalone,.ng-dirty.ng-invalid+validation-message{display:block}\n"], encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: ValidationMessageComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'validation-message',
                    template: `
      <div class="error-container">{{ firstMessage.key + (firstMessage.params ? '(' + firstMessage.params + ')' : '') }}</div>
      <i class="error-icon"></i>
    `,
                    styles: [`
      validation-message {
        display: none;
        width: 100%;
      }
      validation-message.standalone,
      .ng-dirty.ng-invalid + validation-message {
        display: block;
      }
    `],
                    encapsulation: ViewEncapsulation.None
                }]
        }], ctorParameters: function () {
        return [{ type: i1.FormControlName, decorators: [{
                        type: Optional
                    }] }, { type: i1.FormGroupName, decorators: [{
                        type: Optional
                    }] }];
    }, propDecorators: { standalone: [{
                type: HostBinding,
                args: ['class.standalone']
            }], for: [{
                type: Input
            }] } });

class ValidationMessageDirective {
    constructor(viewContainer, componentFactoryResolver, vmComp) {
        this.viewContainer = viewContainer;
        this.componentFactoryResolver = componentFactoryResolver;
        this.vmComp = vmComp;
        this.validationMessageComponent = null;
    }
    ngAfterViewInit() {
        let factory = this.componentFactoryResolver.resolveComponentFactory(this.vmComp);
        this.ngOnDestroy();
        this.validationMessageComponent = this.viewContainer.createComponent(factory, null, this.viewContainer.injector);
        this.validationMessageComponent.changeDetectorRef.detectChanges();
    }
    ngOnDestroy() {
        if (this.validationMessageComponent) {
            this.validationMessageComponent.changeDetectorRef.detach();
        }
    }
}
ValidationMessageDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: ValidationMessageDirective, deps: [{ token: i0.ViewContainerRef }, { token: i0.ComponentFactoryResolver }, { token: ValidationMessageComponent }], target: i0.ɵɵFactoryTarget.Directive });
ValidationMessageDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.2", type: ValidationMessageDirective, selector: "[validationMessage]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: ValidationMessageDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[validationMessage]'
                }]
        }], ctorParameters: function () {
        return [{ type: i0.ViewContainerRef }, { type: i0.ComponentFactoryResolver }, { type: i0.Type, decorators: [{
                        type: Inject,
                        args: [ValidationMessageComponent]
                    }] }];
    } });

class ValidationError {
    get error() {
        return this.control.getError(this.errorKey);
    }
}

class ValidationErrorBuilder {
    build(form, prevKey) {
        let validationErrors = [];
        let formControls = form.controls;
        for (const key in formControls) {
            if (formControls.hasOwnProperty(key)) {
                let fullKey = prevKey ? [prevKey, key].join('.') : key;
                let ctrl = formControls[key];
                if (ctrl instanceof FormControl) {
                    if (!ctrl.valid) {
                        for (const erKey in ctrl.errors) {
                            if (ctrl.errors.hasOwnProperty(erKey)) {
                                let valError = new ValidationError();
                                valError.control = ctrl;
                                valError.controlKey = fullKey;
                                valError.errorKey = erKey;
                                validationErrors.push(valError);
                            }
                        }
                    }
                }
                else {
                    let group = ctrl;
                    validationErrors = validationErrors.concat(this.build(group, fullKey));
                }
            }
        }
        return validationErrors;
    }
}

const declarations$1 = [
    ValidationMessageDirective,
    ValidationMessageComponent,
];
class ValidationMessageModule {
}
ValidationMessageModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: ValidationMessageModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ValidationMessageModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: ValidationMessageModule, declarations: [ValidationMessageDirective,
        ValidationMessageComponent], exports: [ValidationMessageDirective,
        ValidationMessageComponent] });
ValidationMessageModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: ValidationMessageModule, providers: [
        ValidationErrorBuilder,
        {
            provide: ValidationMessageComponent,
            useValue: ValidationMessageComponent
        }
    ] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: ValidationMessageModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: declarations$1,
                    exports: declarations$1,
                    entryComponents: [
                        ValidationMessageComponent
                    ],
                    providers: [
                        ValidationErrorBuilder,
                        {
                            provide: ValidationMessageComponent,
                            useValue: ValidationMessageComponent
                        }
                    ]
                }]
        }] });

class I18NextValidationMessageComponent extends ValidationMessageComponent {
    constructor(i18nextNamespace, formControlName, formGroupName) {
        super(formControlName, formGroupName);
        this.i18nextNamespace = i18nextNamespace;
        this.formControlName = formControlName;
        this.formGroupName = formGroupName;
        this.VALIDATION = 'validation';
    }
    get i18nextKey() {
        if (!this.firstMessage.key)
            return '';
        let specificKey = [this.VALIDATION, ['control_specific', this.controlPath, this.firstMessage.key].join('.')].join(':');
        let commonKey = [this.VALIDATION, this.firstMessage.key].join(':');
        let i18nextKeys = [];
        if (this.i18nextNamespace && this.i18nextNamespace !== this.VALIDATION) {
            i18nextKeys.push([this.i18nextNamespace, specificKey].join('.'));
            i18nextKeys.push([this.i18nextNamespace, commonKey].join('.'));
        }
        i18nextKeys.push(specificKey);
        i18nextKeys.push(commonKey);
        return i18nextKeys;
    }
}
I18NextValidationMessageComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: I18NextValidationMessageComponent, deps: [{ token: I18NEXT_NAMESPACE }, { token: i1.FormControlName, optional: true }, { token: i1.FormGroupName, optional: true }], target: i0.ɵɵFactoryTarget.Component });
I18NextValidationMessageComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.2.2", type: I18NextValidationMessageComponent, selector: "i18next-validation-message", usesInheritance: true, ngImport: i0, template: `
      <div class="error-container">{{ i18nextKey | i18nextCap: firstMessage.params }}</div>
      <i class="error-icon"></i>
    `, isInline: true, styles: ["i18next-validation-message{display:none;width:100%;position:relative}i18next-validation-message.standalone,.ng-dirty.ng-invalid+i18next-validation-message{display:block}\n"], pipes: { "i18nextCap": i2.I18NextCapPipe }, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: I18NextValidationMessageComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'i18next-validation-message',
                    template: `
      <div class="error-container">{{ i18nextKey | i18nextCap: firstMessage.params }}</div>
      <i class="error-icon"></i>
    `,
                    styles: [`
      i18next-validation-message {
        display: none;
        width: 100%;
        position: relative;
      }
      i18next-validation-message.standalone,
      .ng-dirty.ng-invalid + i18next-validation-message {
        display: block;
      }
    `],
                    encapsulation: ViewEncapsulation.None
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Inject,
                        args: [I18NEXT_NAMESPACE]
                    }] }, { type: i1.FormControlName, decorators: [{
                        type: Optional
                    }] }, { type: i1.FormGroupName, decorators: [{
                        type: Optional
                    }] }];
    } });

const declarations = [
    I18NextValidationMessageComponent,
];
const providers = [
    {
        provide: ValidationMessageComponent,
        useValue: I18NextValidationMessageComponent
    }
];
class I18NextValidationMessageModule {
}
I18NextValidationMessageModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: I18NextValidationMessageModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
I18NextValidationMessageModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: I18NextValidationMessageModule, declarations: [I18NextValidationMessageComponent], imports: [I18NextModule,
        ValidationMessageModule], exports: [I18NextValidationMessageComponent, ValidationMessageModule] });
I18NextValidationMessageModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: I18NextValidationMessageModule, providers: providers, imports: [[
            I18NextModule,
            ValidationMessageModule
        ], ValidationMessageModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.2", ngImport: i0, type: I18NextValidationMessageModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: declarations,
                    entryComponents: declarations,
                    exports: [
                        declarations,
                        ValidationMessageModule
                    ],
                    imports: [
                        I18NextModule,
                        ValidationMessageModule
                    ],
                    providers: providers
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { I18NextValidationMessageComponent, I18NextValidationMessageModule, ValidationError, ValidationErrorBuilder, ValidationMessage, ValidationMessageComponent, ValidationMessageDirective, ValidationMessageModule, declarations$1 as declarations, providers };
//# sourceMappingURL=angular-validation-message.mjs.map
